summaryrefslogtreecommitdiff
path: root/receiver.h
diff options
context:
space:
mode:
authorTobias Grimm <tobias@e-tobi.loc>2009-04-23 23:40:38 +0200
committerTobias Grimm <tobias@e-tobi.loc>2009-06-20 18:17:42 +0200
commite125a3bbd31042b4d8d72171f19c1006bee06282 (patch)
tree4aac3fff10bf0b33e2d02792e379dc29b1af870f /receiver.h
parent4de3caa67369af756d2ef008ad26453c9c4065ad (diff)
downloadvdr-patches-e125a3bbd31042b4d8d72171f19c1006bee06282.tar.gz
vdr-patches-e125a3bbd31042b4d8d72171f19c1006bee06282.tar.bz2
ttxtsubs: Record teletext (subtitels) PID
(provided by Rolf Ahrenberg)
Diffstat (limited to 'receiver.h')
-rw-r--r--receiver.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/receiver.h b/receiver.h
index 35930d2..97d2b0f 100644
--- a/receiver.h
+++ b/receiver.h
@@ -38,10 +38,10 @@ protected:
///< will be delivered only ONCE, so the cReceiver must make sure that
///< it will be able to buffer the data if necessary.
public:
- cReceiver(tChannelID ChannelID, int Priority, int Pid, const int *Pids1 = NULL, const int *Pids2 = NULL, const int *Pids3 = NULL);
+ cReceiver(tChannelID ChannelID, int Priority, int Pid, const int *Pids1 = NULL, const int *Pids2 = NULL, const int *Pids3 = NULL, const int *Pids4 = NULL);
///< Creates a new receiver for the channel with the given ChannelID with
///< the given Priority. Pid is a single PID (typically the video PID), while
///< Pids1...Pids3 are pointers to zero terminated lists of PIDs.
///< If any of these PIDs are 0, they will be silently ignored.
///< The total number of non-zero PIDs must not exceed MAXRECEIVEPIDS.
///< Priority may be any value in the range -99..99. Negative values indicate
@@ -38,10 +38,10 @@ protected:
///< Creates a new receiver for the channel with the given ChannelID with
///< the given Priority. Pid is a single PID (typically the video PID), while
- ///< Pids1...Pids3 are pointers to zero terminated lists of PIDs.
+ ///< Pids1...Pids4 are pointers to zero terminated lists of PIDs.
///< If any of these PIDs are 0, they will be silently ignored.
///< The total number of non-zero PIDs must not exceed MAXRECEIVEPIDS.